'''
Manage Azure Service Bus Subscription
'''
from .... pyaz_utils import _call_az
from . import rule


def create(name, namespace_name, resource_group, topic_name, auto_delete_on_idle=None, dead_letter_on_filter_exceptions=None, default_message_time_to_live=None, enable_batched_operations=None, enable_dead_lettering_on_message_expiration=None, enable_session=None, forward_dead_lettered_messages_to=None, forward_to=None, lock_duration=None, max_delivery_count=None, status=None):
    '''
    Create the ServiceBus Subscription

    Required Parameters:
    - name -- Name of Subscription
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - topic_name -- Name of Topic

    Optional Parameters:
    - auto_delete_on_idle -- ISO 8601 timeSpan  or duration time format for idle interval after which the topic is automatically deleted. The minimum duration is 5 minutes.
    - dead_letter_on_filter_exceptions -- Allow dead lettering when filter evaluation exceptions occur.
    - default_message_time_to_live -- ISO 8601 or duration time format for Default message timespan to live value. This is the duration after which the message expires, starting from when the message is sent to Service Bus. This is the default value used when TimeToLive is not set on a message itself.
    - enable_batched_operations -- Allow server-side batched operations.
    - enable_dead_lettering_on_message_expiration -- A boolean Value that indicates whether a subscription has dead letter support when a message expires.
    - enable_session -- A boolean value indicating if a subscription supports the concept of sessions.
    - forward_dead_lettered_messages_to -- Queue/Topic name to forward the Dead Letter message
    - forward_to -- Queue/Topic name to forward the messages
    - lock_duration -- ISO 8601 or duration format (day:minute:seconds) for lock duration timespan for the subscription. The default value is 1 minute.
    - max_delivery_count -- Number of maximum deliveries.
    - status -- Enumerates the possible values for the status of a messaging entity.
    '''
    return _call_az("az servicebus topic subscription create", locals())


def show(name, namespace_name, resource_group, topic_name):
    '''
    Shows Service Bus Subscription Details

    Required Parameters:
    - name -- Name of Subscription
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - topic_name -- Name of Topic
    '''
    return _call_az("az servicebus topic subscription show", locals())


def list(namespace_name, resource_group, topic_name, skip=None, top=None):
    '''
    List the Subscription by Service Bus Topic

    Required Parameters:
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - topic_name -- Name of Topic

    Optional Parameters:
    - skip -- Skip is only used if a previous operation returned a partial result. If a previous response contains a nextLink element, the value of the nextLink element will include a skip parameter that specifies a starting point to use for subsequent calls.
    - top -- May be used to limit the number of results to the most recent N usageDetails.
    '''
    return _call_az("az servicebus topic subscription list", locals())


def delete(name, namespace_name, resource_group, topic_name):
    '''
    Deletes the Service Bus Subscription

    Required Parameters:
    - name -- Name of Subscription
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - topic_name -- Name of Topic
    '''
    return _call_az("az servicebus topic subscription delete", locals())


def update(name, namespace_name, resource_group, topic_name, add=None, auto_delete_on_idle=None, dead_letter_on_filter_exceptions=None, default_message_time_to_live=None, enable_batched_operations=None, enable_dead_lettering_on_message_expiration=None, enable_session=None, force_string=None, forward_dead_lettered_messages_to=None, forward_to=None, lock_duration=None, max_delivery_count=None, remove=None, set=None, status=None):
    '''
    Updates the ServiceBus Subscription

    Required Parameters:
    - name -- Name of Subscription
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - topic_name -- Name of Topic

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - auto_delete_on_idle -- ISO 8601 timeSpan  or duration time format for idle interval after which the topic is automatically deleted. The minimum duration is 5 minutes.
    - dead_letter_on_filter_exceptions -- Allow dead lettering when filter evaluation exceptions occur.
    - default_message_time_to_live -- ISO 8601 or duration time format for Default message timespan to live value. This is the duration after which the message expires, starting from when the message is sent to Service Bus. This is the default value used when TimeToLive is not set on a message itself.
    - enable_batched_operations -- Allow server-side batched operations.
    - enable_dead_lettering_on_message_expiration -- A boolean Value that indicates whether a subscription has dead letter support when a message expires.
    - enable_session -- A boolean value indicating if a subscription supports the concept of sessions.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - forward_dead_lettered_messages_to -- Queue/Topic name to forward the Dead Letter message
    - forward_to -- Queue/Topic name to forward the messages
    - lock_duration -- ISO 8601 or duration format (day:minute:seconds) for lock duration timespan for the subscription. The default value is 1 minute.
    - max_delivery_count -- Number of maximum deliveries.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - status -- Enumerates the possible values for the status of a messaging entity.
    '''
    return _call_az("az servicebus topic subscription update", locals())




from ... pyaz_utils import _call_az

def list():
    return _call_az("az billing enrollment-account list", locals())


def show(name):
    '''
    

    Required Parameters:
    - name -- name of the enrollment account
    '''
    return _call_az("az billing enrollment-account show", locals())




from .... pyaz_utils import _call_az

def show(name, resource_group, scope_name):
    '''
    Show a scoped resource of a private link scope resource.

    Required Parameters:
    - name -- Name of the assigned resource.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - scope_name -- Name of the Azure Monitor Private Link Scope.
    '''
    return _call_az("az monitor private-link-scope scoped-resource show", locals())


def list(resource_group, scope_name):
    '''
    List all scoped resource of a private link scope resource.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - scope_name -- Name of the Azure Monitor Private Link Scope.
    '''
    return _call_az("az monitor private-link-scope scoped-resource list", locals())


def create(linked_resource, name, resource_group, scope_name):
    '''
    Create a scoped resource for a private link scope resource.

    Required Parameters:
    - linked_resource -- ARM resource ID of the linked resource. It should be one of log analytics workspace or application insights component.
    - name -- Name of the assigned resource.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - scope_name -- Name of the Azure Monitor Private Link Scope.
    '''
    return _call_az("az monitor private-link-scope scoped-resource create", locals())


def delete(name, resource_group, scope_name, yes=None):
    '''
    Delete a scoped resource of a private link scope resource.

    Required Parameters:
    - name -- Name of the assigned resource.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - scope_name -- Name of the Azure Monitor Private Link Scope.

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az monitor private-link-scope scoped-resource delete", locals())




'''
Manage autoscaling profiles.
'''
from .... pyaz_utils import _call_az

def create(autoscale_name, count, name, resource_group, timezone, copy_rules=None, end=None, max_count=None, min_count=None, recurrence=None, start=None):
    '''
    Create a fixed or recurring autoscale profile.

    Required Parameters:
    - autoscale_name -- Name of the autoscale settings.
    - count -- The numer of instances to use. If used with --min/max-count, the default number of instances to use.
    - name -- Name of the autoscale profile.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - timezone -- None

    Optional Parameters:
    - copy_rules -- Name of an existing schedule from which to copy the scaling rules for the new schedule.
    - end -- End time. Format: date (yyyy-mm-dd) time (hh:mm:ss.xxxxx)
    - max_count -- The maximum number of instances.
    - min_count -- The minimum number of instances.
    - recurrence -- None
    - start -- Start time. Format: date (yyyy-mm-dd) time (hh:mm:ss.xxxxx)
    '''
    return _call_az("az monitor autoscale profile create", locals())


def list(autoscale_name, resource_group):
    '''
    List autoscale profiles.

    Required Parameters:
    - autoscale_name -- Name of the autoscale settings.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor autoscale profile list", locals())


def show(autoscale_name, name, resource_group):
    '''
    Show details of an autoscale profile.

    Required Parameters:
    - autoscale_name -- Name of the autoscale settings.
    - name -- Name of the autoscale profile.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor autoscale profile show", locals())


def delete(autoscale_name, name, resource_group):
    '''
    Delete an autoscale profile.

    Required Parameters:
    - autoscale_name -- Name of the autoscale settings.
    - name -- Name of the autoscale profile.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor autoscale profile delete", locals())


def list_timezones(offset=None, search_query=None):
    '''
    Look up time zone information.

    Optional Parameters:
    - offset -- Filter results based on UTC hour offset.
    - search_query -- Query text to find.
    '''
    return _call_az("az monitor autoscale profile list-timezones", locals())




'''
Manage a server's keys.
'''
from .... pyaz_utils import _call_az

def create(kid, resource_group, server):
    '''
    Creates a server key.

    Required Parameters:
    - kid -- The Azure Key Vault key identifier of the server key. An example key identifier is "https://YourVaultName.vault.azure.net/keys/YourKeyName/01234567890123456789012345678901"
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql server key create", locals())


def delete(kid, resource_group, server):
    '''
    Deletes a server key.

    Required Parameters:
    - kid -- The Azure Key Vault key identifier of the server key. An example key identifier is "https://YourVaultName.vault.azure.net/keys/YourKeyName/01234567890123456789012345678901"
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql server key delete", locals())


def show(kid, resource_group, server):
    '''
    Shows a server key.

    Required Parameters:
    - kid -- The Azure Key Vault key identifier of the server key. An example key identifier is "https://YourVaultName.vault.azure.net/keys/YourKeyName/01234567890123456789012345678901"
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql server key show", locals())


def list(resource_group, server):
    '''
    

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql server key list", locals())




from .... pyaz_utils import _call_az
from . import keys


def create(name, namespace_name, queue_name, resource_group, rights=None):
    '''
    Create Authorization Rule for the given Service Bus Queue.

    Required Parameters:
    - name -- Name of Authorization Rule
    - namespace_name -- Name of Namespace
    - queue_name -- Name of Queue
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - rights -- Space-separated list of Authorization rule rights
    '''
    return _call_az("az servicebus queue authorization-rule create", locals())


def show(name, namespace_name, queue_name, resource_group):
    '''
    show properties of Authorization Rule for the given Service Bus Queue.

    Required Parameters:
    - name -- Name of Queue Authorization Rule
    - namespace_name -- Name of Namespace
    - queue_name -- Name of Queue
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az servicebus queue authorization-rule show", locals())


def list(namespace_name, queue_name, resource_group):
    '''
    List of Authorization Rule by Service Bus Queue.

    Required Parameters:
    - namespace_name -- Name of Namespace
    - queue_name -- Name of Queue
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az servicebus queue authorization-rule list", locals())


def delete(name, namespace_name, queue_name, resource_group):
    '''
    Delete the Authorization Rule of Service Bus Queue

    Required Parameters:
    - name -- Name of Queue Authorization Rule
    - namespace_name -- Name of Namespace
    - queue_name -- Name of Queue
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az servicebus queue authorization-rule delete", locals())


def update(name, namespace_name, queue_name, resource_group, rights, add=None, force_string=None, remove=None, set=None):
    '''
    Update Authorization Rule for the given Service Bus Queue.

    Required Parameters:
    - name -- Name of Queue Authorization Rule
    - namespace_name -- Name of Namespace
    - queue_name -- Name of Queue
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rights -- Space-separated list of Authorization rule rights

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az servicebus queue authorization-rule update", locals())




from ... pyaz_utils import _call_az

def create(name, storage_account, access_tier=None, enabled_protocols=None, metadata=None, quota=None, resource_group=None, root_squash=None):
    '''
    Create a new Azure file share under the specified storage account.

    Required Parameters:
    - name -- The file share name.
    - storage_account -- The name or ID of the storage account.

    Optional Parameters:
    - access_tier -- Access tier for specific share. GpV2 account can choose between TransactionOptimized (default), Hot, and Cool. FileStorage account can choose Premium.
    - enabled_protocols -- Immutable property for file shares protocol. NFS protocol will be only available for premium file shares (file shares in the FileStorage account type).
    - metadata -- Metadata in space-separated key=value pairs that is associated with the share. This overwrites any existing metadata
    - quota -- The maximum size of the share in gigabytes. Must be greater than 0, and less than or equal to 5TB (5120). For Large File Shares, the maximum size is 102400.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - root_squash -- Reduction of the access rights for the remote superuser.
    '''
    return _call_az("az storage share-rm create", locals())


def delete(name, storage_account, include=None, resource_group=None, snapshot=None, yes=None):
    '''
    Delete the specified Azure file share or share snapshot.

    Required Parameters:
    - name -- The file share name.
    - storage_account -- The name or ID of the storage account.

    Optional Parameters:
    - include -- Optional. Valid values are: snapshots, leased-snapshots, none. The default value is snapshots. For 'snapshots', the file share is deleted including all of its file share snapshots. If the file share contains leased-snapshots, the deletion fails. For 'leased-snapshots', the file share is deleted included all of its file share snapshots (leased/unleased). For 'none', the file share is deleted if it has no share snapshots. If the file share contains any snapshots (leased or unleased), the deletion fails.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - snapshot -- The DateTime value that specifies the share snapshot to retrieve.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az storage share-rm delete", locals())


def exists(name, storage_account, resource_group=None):
    '''
    Check for the existence of an Azure file share.

    Required Parameters:
    - name -- The file share name.
    - storage_account -- The name or ID of the storage account.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage share-rm exists", locals())


def list(storage_account, include_deleted=None, include_snapshot=None, resource_group=None):
    '''
    List the Azure file shares under the specified storage account.

    Required Parameters:
    - storage_account -- The name or ID of the storage account.

    Optional Parameters:
    - include_deleted -- Include soft deleted file shares when specified.
    - include_snapshot -- Include file share snapshots when specified.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage share-rm list", locals())


def show(name, storage_account, expand=None, resource_group=None, snapshot=None):
    '''
    Show the properties for a specified Azure file share or share snapshot.

    Required Parameters:
    - name -- The file share name.
    - storage_account -- The name or ID of the storage account.

    Optional Parameters:
    - expand -- Optional, used to expand the properties within share's properties. Valid values are: stats. Should be passed as a string with delimiter ','.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - snapshot -- The DateTime value that specifies the share snapshot to retrieve.
    '''
    return _call_az("az storage share-rm show", locals())


def update(name, storage_account, access_tier=None, add=None, force_string=None, metadata=None, quota=None, remove=None, resource_group=None, root_squash=None, set=None):
    '''
    Update the properties for an Azure file share.

    Required Parameters:
    - name -- The file share name.
    - storage_account -- The name or ID of the storage account.

    Optional Parameters:
    - access_tier -- Access tier for specific share. GpV2 account can choose between TransactionOptimized (default), Hot, and Cool. FileStorage account can choose Premium.
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - metadata -- Metadata in space-separated key=value pairs that is associated with the share. This overwrites any existing metadata
    - quota -- The maximum size of the share in gigabytes. Must be greater than 0, and less than or equal to 5TB (5120). For Large File Shares, the maximum size is 102400.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - root_squash -- Reduction of the access rights for the remote superuser.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az storage share-rm update", locals())


def stats(name, storage_account, resource_group=None):
    '''
    Get the usage bytes of the data stored on the share.

    Required Parameters:
    - name -- The file share name.
    - storage_account -- The name or ID of the storage account.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage share-rm stats", locals())


def restore(deleted_version, name, storage_account, resource_group=None, restored_name=None):
    '''
    Restore a file share within a valid retention days if share soft delete is enabled.

    Required Parameters:
    - deleted_version -- Identify the version of the deleted share that will be restored.
    - name -- The file share name. Identify the name of the deleted share that will be restored.
    - storage_account -- The name or ID of the storage account.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - restored_name -- A new file share name to be restored. If not specified, deleted share name will be used.
    '''
    return _call_az("az storage share-rm restore", locals())


def snapshot(name, storage_account, access_tier=None, enabled_protocols=None, metadata=None, quota=None, resource_group=None, root_squash=None):
    '''
    Create a snapshot of an existing share under the specified account.

    Required Parameters:
    - name -- The file share name.
    - storage_account -- The name or ID of the storage account.

    Optional Parameters:
    - access_tier -- Access tier for specific share. GpV2 account can choose between TransactionOptimized (default), Hot, and Cool. FileStorage account can choose Premium.
    - enabled_protocols -- Immutable property for file shares protocol. NFS protocol will be only available for premium file shares (file shares in the FileStorage account type).
    - metadata -- Metadata in space-separated key=value pairs that is associated with the share. This overwrites any existing metadata
    - quota -- The maximum size of the share in gigabytes. Must be greater than 0, and less than or equal to 5TB (5120). For Large File Shares, the maximum size is 102400.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - root_squash -- Reduction of the access rights for the remote superuser.
    '''
    return _call_az("az storage share-rm snapshot", locals())




'''
Manage web app logs.
'''
from ... pyaz_utils import _call_az
from . import deployment


def tail(name, resource_group, provider=None, slot=None):
    '''
    Start live log tracing for a web app.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - provider -- By default all live traces configured by `az webapp log config` will be shown, but you can scope to certain providers/folders, e.g. 'application', 'http', etc. For details, check out https://github.com/projectkudu/kudu/wiki/Diagnostic-Log-Stream
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp log tail", locals())


def download(name, resource_group, log_file=None, slot=None):
    '''
    Download a web app's log history as a zip file.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - log_file -- the downloaded zipped log file path
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp log download", locals())


def config(name, resource_group, application_logging=None, detailed_error_messages=None, docker_container_logging=None, failed_request_tracing=None, level=None, slot=None, web_server_logging=None):
    '''
    Configure logging for a web app.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - application_logging -- configure application logging
    - detailed_error_messages -- configure detailed error messages
    - docker_container_logging -- configure gathering STDOUT and STDERR output from container
    - failed_request_tracing -- configure failed request tracing
    - level -- logging level
    - slot -- the name of the slot. Default to the productions slot if not specified
    - web_server_logging -- configure Web server logging
    '''
    return _call_az("az webapp log config", locals())


def show(name, resource_group, slot=None):
    '''
    Get the details of a web app's logging configuration.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp log show", locals())




'''
View and manage Advanced Threat Protection settings for storage accounts.
'''
from .... pyaz_utils import _call_az

def show(resource_group, storage_account):
    '''
    Display Advanced Threat Protection settings for a storage account.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - storage_account -- Name of an existing storage account.
    '''
    return _call_az("az security atp storage show", locals())


def update(is_enabled, resource_group, storage_account):
    '''
    Toggle status of Advanced Threat Protection for a storage account.

    Required Parameters:
    - is_enabled -- Enable or disable Advanced Threat Protection for a received storage account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - storage_account -- Name of an existing storage account.
    '''
    return _call_az("az security atp storage update", locals())




'''
Manage network security group rules.
'''
from .... pyaz_utils import _call_az

def delete(name, nsg_name, resource_group):
    '''
    Delete a network security group rule.

    Required Parameters:
    - name -- Name of the network security group rule
    - nsg_name -- Name of the network security group
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network nsg rule delete", locals())


def list(nsg_name, resource_group, include_default=None):
    '''
    List all rules in a network security group.

    Required Parameters:
    - nsg_name -- Name of the network security group
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - include_default -- Include default security rules in the output.
    '''
    return _call_az("az network nsg rule list", locals())


def show(name, nsg_name, resource_group):
    '''
    Get the details of a network security group rule.

    Required Parameters:
    - name -- Name of the network security group rule
    - nsg_name -- Name of the network security group
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network nsg rule show", locals())


def create(name, nsg_name, priority, resource_group, access=None, description=None, destination_address_prefixes=None, destination_asgs=None, destination_port_ranges=None, direction=None, protocol=None, source_address_prefixes=None, source_asgs=None, source_port_ranges=None):
    '''
    Create a network security group rule.

    Required Parameters:
    - name -- Name of the network security group rule
    - nsg_name -- Name of the network security group
    - priority -- Rule priority, between 100 (highest priority) and 4096 (lowest priority). Must be unique for each rule in the collection.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - access -- None
    - description -- Rule description
    - destination_address_prefixes -- Space-separated list of CIDR prefixes or IP ranges. Alternatively, specify ONE of 'VirtualNetwork', 'AzureLoadBalancer', 'Internet' or '*' to match all IPs. Besides, it also supports all available Service Tags like 'ApiManagement', 'SqlManagement', 'AzureMonitor', etc.
    - destination_asgs -- Space-separated list of application security group names or IDs. Limited by backend server, temporarily this argument only supports one application security group name or ID
    - destination_port_ranges -- Space-separated list of ports or port ranges between 0-65535. Use '*' to match all ports.
    - direction -- None
    - protocol -- Network protocol this rule applies to.
    - source_address_prefixes -- Space-separated list of CIDR prefixes or IP ranges. Alternatively, specify ONE of 'VirtualNetwork', 'AzureLoadBalancer', 'Internet' or '*' to match all IPs. Besides, it also supports all available Service Tags like 'ApiManagement', 'SqlManagement', 'AzureMonitor', etc.
    - source_asgs -- Space-separated list of application security group names or IDs. Limited by backend server, temporarily this argument only supports one application security group name or ID
    - source_port_ranges -- Space-separated list of ports or port ranges between 0-65535. Use '*' to match all ports.
    '''
    return _call_az("az network nsg rule create", locals())


def update(name, nsg_name, resource_group, access=None, add=None, description=None, destination_address_prefixes=None, destination_asgs=None, destination_port_ranges=None, direction=None, force_string=None, priority=None, protocol=None, remove=None, set=None, source_address_prefixes=None, source_asgs=None, source_port_ranges=None):
    '''
    Update a network security group rule.

    Required Parameters:
    - name -- Name of the network security group rule
    - nsg_name -- Name of the network security group
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - access -- None
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - description -- Rule description
    - destination_address_prefixes -- Space-separated list of CIDR prefixes or IP ranges. Alternatively, specify ONE of 'VirtualNetwork', 'AzureLoadBalancer', 'Internet' or '*' to match all IPs. Besides, it also supports all available Service Tags like 'ApiManagement', 'SqlManagement', 'AzureMonitor', etc.
    - destination_asgs -- Space-separated list of application security group names or IDs. Limited by backend server, temporarily this argument only supports one application security group name or ID
    - destination_port_ranges -- Space-separated list of ports or port ranges between 0-65535. Use '*' to match all ports.
    - direction -- None
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - priority -- Rule priority, between 100 (highest priority) and 4096 (lowest priority). Must be unique for each rule in the collection.
    - protocol -- Network protocol this rule applies to.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - source_address_prefixes -- Space-separated list of CIDR prefixes or IP ranges. Alternatively, specify ONE of 'VirtualNetwork', 'AzureLoadBalancer', 'Internet' or '*' to match all IPs. Besides, it also supports all available Service Tags like 'ApiManagement', 'SqlManagement', 'AzureMonitor', etc.
    - source_asgs -- Space-separated list of application security group names or IDs. Limited by backend server, temporarily this argument only supports one application security group name or ID
    - source_port_ranges -- Space-separated list of ports or port ranges between 0-65535. Use '*' to match all ports.
    '''
    return _call_az("az network nsg rule update", locals())




'''
Manage custom domains.
'''
from ... pyaz_utils import _call_az

def create(contact_info, hostname, resource_group, accept_terms=None, auto_renew=None, dryrun=None, privacy=None, tags=None):
    '''
    Create and purchase a custom domain.

    Required Parameters:
    - contact_info -- The file path to a JSON object with your contact info for domain registration. Please see the following link for the format of the JSON file expected: https://github.com/AzureAppServiceCLI/appservice_domains_templates/blob/master/contact_info.json
    - hostname -- Name of the custom domain
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - accept_terms -- By using this flag, you are accepting the conditions shown using the --show-hostname-purchase-terms flag. 
    - auto_renew -- Enable auto-renew on the domain
    - dryrun -- Show summary of the purchase and create operation instead of executing it
    - privacy -- Enable privacy protection
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az appservice domain create", locals())


def show_terms(hostname):
    '''
    Show the legal terms for purchasing and creating a custom domain.

    Required Parameters:
    - hostname -- Name of the custom domain
    '''
    return _call_az("az appservice domain show-terms", locals())




from ..... pyaz_utils import _call_az

def show(name, resource_group, workspace_name):
    '''
    Get a SQL pool's auditing policy.

    Required Parameters:
    - name -- The SQL pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse sql pool audit-policy show", locals())


def update(name, resource_group, workspace_name, actions=None, add=None, blob_storage_target_state=None, enable_azure_monitor=None, event_hub=None, event_hub_authorization_rule_id=None, event_hub_target_state=None, force_string=None, log_analytics_target_state=None, log_analytics_workspace_resource_id=None, remove=None, retention_days=None, set=None, state=None, storage_account=None, storage_endpoint=None, storage_key=None, storage_subscription=None, use_secondary_key=None):
    '''
    Update a SQL pool's auditing policy.

    Required Parameters:
    - name -- The SQL pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - actions -- List of actions and action groups to audit.
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - blob_storage_target_state -- Indicate whether blob storage is a destination for audit records.
    - enable_azure_monitor -- Whether enabling azure monitor target or not.
    - event_hub -- The name of the event hub. If none is specified when providing event_hub_authorization_rule_id, the default event hub will be selected.
    - event_hub_authorization_rule_id -- The resource Id for the event hub authorization rule.
    - event_hub_target_state -- Indicate whether event hub is a destination for audit records.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - log_analytics_target_state -- Indicate whether log analytics is a destination for audit records.
    - log_analytics_workspace_resource_id -- The workspace ID (resource ID of a Log Analytics workspace) for a Log Analytics workspace to which you would like to send Audit Logs.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - retention_days -- The number of days to retain audit logs.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - state -- Auditing policy state
    - storage_account -- Name of the storage account.
    - storage_endpoint -- The storage account endpoint.
    - storage_key -- Access key for the storage account.
    - storage_subscription -- The subscription id of storage account
    - use_secondary_key -- Indicates whether using the secondary storeage key or not
    '''
    return _call_az("az synapse sql pool audit-policy update", locals())




from .... pyaz_utils import _call_az
from . import a, aaaa, cname, mx, ptr, soa, srv, txt


def list(resource_group, zone_name, record_type=None):
    '''
    List all record sets within a Private DNS zone.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - zone_name -- The name of the Private DNS zone.

    Optional Parameters:
    - record_type -- ==SUPPRESS==
    '''
    return _call_az("az network private-dns record-set list", locals())




from .... pyaz_utils import _call_az

def show(resource_group, server):
    '''
    Gets a server's secure connection policy.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql server conn-policy show", locals())


def update(connection_type, resource_group, server):
    '''
    Updates a server's secure connection policy.

    Required Parameters:
    - connection_type -- The required parameters for updating a secure connection policy. The value is default
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql server conn-policy update", locals())




from ..... pyaz_utils import _call_az

def create(resource_group, storage_accounts, type, workspace_name):
    '''
    Create some linked storage accounts for log analytics workspace.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - storage_accounts -- List of Name or ID of Azure Storage Account.
    - type -- Data source type for the linked storage account.
    - workspace_name -- Name of the Log Analytics Workspace.
    '''
    return _call_az("az monitor log-analytics workspace linked-storage create", locals())


def add(resource_group, storage_accounts, type, workspace_name):
    '''
    Add some linked storage accounts with specific data source type for log analytics workspace.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - storage_accounts -- List of Name or ID of Azure Storage Account.
    - type -- Data source type for the linked storage account.
    - workspace_name -- Name of the Log Analytics Workspace.
    '''
    return _call_az("az monitor log-analytics workspace linked-storage add", locals())


def remove(resource_group, storage_accounts, type, workspace_name):
    '''
    Remove some linked storage accounts with specific data source type for log analytics workspace

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - storage_accounts -- List of Name or ID of Azure Storage Account.
    - type -- Data source type for the linked storage account.
    - workspace_name -- Name of the Log Analytics Workspace.
    '''
    return _call_az("az monitor log-analytics workspace linked-storage remove", locals())


def delete(resource_group, type, workspace_name, yes=None):
    '''
    Delete all linked storage accounts with specific data source type for log analytics workspace.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - type -- Data source type for the linked storage account.
    - workspace_name -- Name of the Log Analytics Workspace.

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az monitor log-analytics workspace linked-storage delete", locals())


def show(resource_group, type, workspace_name):
    '''
    List all linked storage accounts with specific data source type for a log analytics workspace.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - type -- Data source type for the linked storage account.
    - workspace_name -- Name of the Log Analytics Workspace.
    '''
    return _call_az("az monitor log-analytics workspace linked-storage show", locals())


def list(resource_group, workspace_name):
    '''
    List all linked storage accounts for a log analytics workspace.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- Name of the Log Analytics Workspace.
    '''
    return _call_az("az monitor log-analytics workspace linked-storage list", locals())




from ... pyaz_utils import _call_az

def create(name, storage_account, default_encryption_scope=None, deny_encryption_scope_override=None, enable_vlw=None, fail_on_exist=None, metadata=None, public_access=None, resource_group=None, root_squash=None):
    '''
    Create a new container under the specified storage account.

    Required Parameters:
    - name -- The container name.
    - storage_account -- The name or ID of the storage account.

    Optional Parameters:
    - default_encryption_scope -- Default the container to use specified encryption scope for all writes.
    - deny_encryption_scope_override -- Block override of encryption scope from the container default.
    - enable_vlw -- The object level immutability property of the container. The property is immutable and can only be set to true at the container creation time. Existing containers must undergo a migration process.
    - fail_on_exist -- Throw an exception if the container already exists.
    - metadata -- Metadata in space-separated key=value pairs. This overwrites any existing metadata.
    - public_access -- Specify whether data in the container may be accessed publicly.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - root_squash -- Enable NFSv3 squash on blob container.
    '''
    return _call_az("az storage container-rm create", locals())


def delete(name, storage_account, resource_group=None, yes=None):
    '''
    Delete the specified container under its account.

    Required Parameters:
    - name -- The container name.
    - storage_account -- The name or ID of the storage account.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az storage container-rm delete", locals())


def update(name, storage_account, add=None, default_encryption_scope=None, deny_encryption_scope_override=None, force_string=None, metadata=None, public_access=None, remove=None, resource_group=None, root_squash=None, set=None):
    '''
    Update the properties for a container.

    Required Parameters:
    - name -- The container name.
    - storage_account -- The name or ID of the storage account.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - default_encryption_scope -- Default the container to use specified encryption scope for all writes.
    - deny_encryption_scope_override -- Block override of encryption scope from the container default.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - metadata -- Metadata in space-separated key=value pairs. This overwrites any existing metadata.
    - public_access -- Specify whether data in the container may be accessed publicly.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - root_squash -- Enable NFSv3 squash on blob container.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az storage container-rm update", locals())


def list(storage_account, include_deleted=None, resource_group=None):
    '''
    List all containers under the specified storage account.

    Required Parameters:
    - storage_account -- The name or ID of the storage account.

    Optional Parameters:
    - include_deleted -- Include soft deleted containers when specified.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage container-rm list", locals())


def exists(name, storage_account, resource_group=None):
    '''
    Check for the existence of a container.

    Required Parameters:
    - name -- The container name.
    - storage_account -- The name or ID of the storage account.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage container-rm exists", locals())


def show(name, storage_account, resource_group=None):
    '''
    Show the properties for a specified container.

    Required Parameters:
    - name -- The container name.
    - storage_account -- The name or ID of the storage account.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage container-rm show", locals())


def migrate_vlw(name, storage_account, no_wait=None, resource_group=None):
    '''
    Migrate a blob container from container level WORM to object level immutability enabled container.

    Required Parameters:
    - name -- The container name.
    - storage_account -- The name or ID of the storage account.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage container-rm migrate-vlw", locals())




from ... pyaz_utils import _call_az

def create(file, name, workspace_name, no_wait=None):
    '''
    Create a linked service.

    Required Parameters:
    - file -- Properties may be supplied from a JSON file using the `@{path}` syntax or a JSON string.
    - name -- The linked service name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse linked-service create", locals())


def set(file, name, workspace_name, no_wait=None):
    '''
    Update an exist linked service.

    Required Parameters:
    - file -- Properties may be supplied from a JSON file using the `@{path}` syntax or a JSON string.
    - name -- The linked service name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse linked-service set", locals())


def update(file, name, workspace_name, no_wait=None):
    '''
    Update an exist linked service.

    Required Parameters:
    - file -- Properties may be supplied from a JSON file using the `@{path}` syntax or a JSON string.
    - name -- The linked service name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse linked-service update", locals())


def list(workspace_name):
    '''
    List linked services.

    Required Parameters:
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse linked-service list", locals())


def show(name, workspace_name):
    '''
    Get a linked service.

    Required Parameters:
    - name -- The linked service name.
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse linked-service show", locals())


def delete(name, workspace_name, no_wait=None, yes=None):
    '''
    Delete a linked service.

    Required Parameters:
    - name -- The linked service name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az synapse linked-service delete", locals())




from ..... pyaz_utils import _call_az

def list(name, namespace_name, resource_group):
    '''
    List the keys and connection strings of Authorization Rule for Service Bus Namespace

    Required Parameters:
    - name -- Name of Namespace Authorization Rule
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az servicebus namespace authorization-rule keys list", locals())


def renew(key, name, namespace_name, resource_group):
    '''
    Regenerate keys of Authorization Rule for the Service Bus Namespace.

    Required Parameters:
    - key -- specifies Primary or Secondary key needs to be reset
    - name -- Name of Namespace Authorization Rule
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az servicebus namespace authorization-rule keys renew", locals())




'''
Manage application owners.
'''
from .... pyaz_utils import _call_az

def list(id):
    '''
    List application owners.

    Required Parameters:
    - id -- identifier uri, application id, or object id of the application
    '''
    return _call_az("az ad app owner list", locals())


def add(id, owner_object_id):
    '''
    Add an application owner.

    Required Parameters:
    - id -- identifier uri, application id, or object id
    - owner_object_id -- owner's object id
    '''
    return _call_az("az ad app owner add", locals())


def remove(id, owner_object_id):
    '''
    Remove an application owner.

    Required Parameters:
    - id -- identifier uri, application id, or object id
    - owner_object_id -- owner's object id
    '''
    return _call_az("az ad app owner remove", locals())




from ..... pyaz_utils import _call_az

def add(connection_monitor, location, name, address=None, address_exclude=None, address_include=None, coverage_level=None, dest_test_groups=None, filter_item=None, filter_type=None, resource_id=None, source_test_groups=None, type=None):
    '''
    Add an endpoint to a connection monitor

    Required Parameters:
    - connection_monitor -- Connection monitor name.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The name of the connection monitor endpoint

    Optional Parameters:
    - address -- Address of the connection monitor endpoint (IP or domain name)
    - address_exclude -- List of address of the endpoint item which needs to be included to the endpoint scope
    - address_include -- List of address of the endpoint item which needs to be included to the endpoint scope
    - coverage_level -- Test coverage for the endpoint
    - dest_test_groups -- Space-separated list of names for test group to reference as destination
    - filter_item -- List of property=value pairs to define filter items. Property currently include: type, address. Property value of type supports 'AgentAddress' only now.
    - filter_type -- The behavior of the endpoint filter. Currently only 'Include' is supported.
    - resource_id -- Resource ID of the connection monitor endpoint
    - source_test_groups -- Space-separated list of names for test group to reference as source
    - type -- The endpoint type
    '''
    return _call_az("az network watcher connection-monitor endpoint add", locals())


def remove(connection_monitor, location, name, test_groups=None):
    '''
    Remove an endpoint from a connection monitor

    Required Parameters:
    - connection_monitor -- Connection monitor name.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The name of the connection monitor endpoint

    Optional Parameters:
    - test_groups -- Space-separated list of names of test group which only need to be affected if specified
    '''
    return _call_az("az network watcher connection-monitor endpoint remove", locals())


def show(connection_monitor, location, name):
    '''
    Show an endpoint from a connection monitor

    Required Parameters:
    - connection_monitor -- Connection monitor name.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The name of the connection monitor endpoint
    '''
    return _call_az("az network watcher connection-monitor endpoint show", locals())


def list(connection_monitor, location):
    '''
    List all endpoints form a connection monitor

    Required Parameters:
    - connection_monitor -- Connection monitor name.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    '''
    return _call_az("az network watcher connection-monitor endpoint list", locals())




from ... pyaz_utils import _call_az
from . import private_endpoint_connection, private_link_resource, scoped_resource


def show(name, resource_group):
    '''
    Show a monitor private link scope resource.

    Required Parameters:
    - name -- Name of the Azure Monitor Private Link Scope.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor private-link-scope show", locals())


def list(resource_group=None):
    '''
    List all monitor private link scope resource.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor private-link-scope list", locals())


def create(name, resource_group, tags=None):
    '''
    Create a private link scope resource.

    Required Parameters:
    - name -- Name of the Azure Monitor Private Link Scope.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az monitor private-link-scope create", locals())


def update(name, resource_group, tags):
    '''
    Update a monitor private link scope resource.

    Required Parameters:
    - name -- Name of the Azure Monitor Private Link Scope.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az monitor private-link-scope update", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete a monitor private link scope resource.

    Required Parameters:
    - name -- Name of the Azure Monitor Private Link Scope.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az monitor private-link-scope delete", locals())




'''
Manage near-realtime metric alert rule dimensions.
'''
from ..... pyaz_utils import _call_az

def create(name, value, operator=None):
    '''
    Build a metric alert rule dimension.

    Required Parameters:
    - name -- Name of the dimension.
    - value -- The values to apply on the operation.

    Optional Parameters:
    - operator -- Dimension operator.
    '''
    return _call_az("az monitor metrics alert dimension create", locals())




'''
Manage IoT Hub certificates.
'''
from .... pyaz_utils import _call_az

def list(hub_name, resource_group=None):
    '''
    Lists all certificates contained within an Azure IoT Hub

    Required Parameters:
    - hub_name -- IoT Hub name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub certificate list", locals())


def show(hub_name, name, resource_group=None):
    '''
    Shows information about a particular Azure IoT Hub certificate.

    Required Parameters:
    - hub_name -- IoT Hub name.
    - name -- A friendly name for the certificate.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub certificate show", locals())


def create(hub_name, name, path, resource_group=None, verified=None):
    '''
    Create/upload an Azure IoT Hub certificate.

    Required Parameters:
    - hub_name -- IoT Hub name.
    - name -- A friendly name for the certificate.
    - path -- The path to the file containing the certificate.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - verified -- A boolean indicating whether or not the certificate is verified.
    '''
    return _call_az("az iot hub certificate create", locals())


def delete(etag, hub_name, name, resource_group=None):
    '''
    Deletes an Azure IoT Hub certificate.

    Required Parameters:
    - etag -- Entity Tag (etag) of the object.
    - hub_name -- IoT Hub name.
    - name -- A friendly name for the certificate.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub certificate delete", locals())


def generate_verification_code(etag, hub_name, name, resource_group=None):
    '''
    Generates a verification code for an Azure IoT Hub certificate.

    Required Parameters:
    - etag -- Entity Tag (etag) of the object.
    - hub_name -- IoT Hub name.
    - name -- A friendly name for the certificate.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub certificate generate-verification-code", locals())


def verify(etag, hub_name, name, path, resource_group=None):
    '''
    Verifies an Azure IoT Hub certificate.

    Required Parameters:
    - etag -- Entity Tag (etag) of the object.
    - hub_name -- IoT Hub name.
    - name -- A friendly name for the certificate.
    - path -- The path to the file containing the certificate.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub certificate verify", locals())


def update(etag, hub_name, name, path, resource_group=None, verified=None):
    '''
    Update an Azure IoT Hub certificate.

    Required Parameters:
    - etag -- Entity Tag (etag) of the object.
    - hub_name -- IoT Hub name.
    - name -- A friendly name for the certificate.
    - path -- The path to the file containing the certificate.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - verified -- A boolean indicating whether or not the certificate is verified.
    '''
    return _call_az("az iot hub certificate update", locals())




'''
Manage Azure NetApp Files (ANF) Account active directories.
'''
from .... pyaz_utils import _call_az

def add(dns, domain, name, password, resource_group, smb_server_name, username, ad_name=None, add=None, administrators=None, aes_encryption=None, allow_local_ldap_users=None, backup_operators=None, force_string=None, kdc_ip=None, ldap_over_tls=None, ldap_signing=None, organizational_unit=None, remove=None, security_operators=None, server_root_ca_cert=None, set=None, tags=None):
    '''
    Add an active directory to the account.

    Required Parameters:
    - dns -- None
    - domain -- None
    - name -- Name of the ANF account.
    - password -- None
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - smb_server_name -- None
    - username -- None

    Optional Parameters:
    - ad_name -- None
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - administrators -- None
    - aes_encryption -- None
    - allow_local_ldap_users -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - backup_operators -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - kdc_ip -- None
    - ldap_over_tls -- None
    - ldap_signing -- None
    - organizational_unit -- None
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - security_operators -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - server_root_ca_cert -- None
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az netappfiles account ad add", locals())


def list(name, resource_group):
    '''
    List the active directories of an account.

    Required Parameters:
    - name -- The name of the ANF account
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az netappfiles account ad list", locals())


def remove(active_directory, name, resource_group):
    '''
    Remove an active directory from the account.

    Required Parameters:
    - active_directory -- None
    - name -- Name of the ANF account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az netappfiles account ad remove", locals())




'''
Manage map with maps
'''
from ... pyaz_utils import _call_az

def list_operation():
    '''
    List operations available for the Maps Resource Provider.
    '''
    return _call_az("az maps map list-operation", locals())




'''
Manage DNS domains in Azure.
'''
from ... pyaz_utils import _call_az
from . import record_set, zone


def list_references(parameters):
    '''
    

    Required Parameters:
    - parameters -- Properties for dns resource reference request.
    '''
    return _call_az("az network dns list-references", locals())




'''
Manage file shares that use the SMB 3.0 protocol.
'''
from ... pyaz_utils import _call_az
from . import copy, metadata


def list(share_name, account_key=None, account_name=None, connection_string=None, exclude_dir=None, marker=None, num_results=None, path=None, sas_token=None, snapshot=None, timeout=None):
    '''
    List files and directories in a share.

    Required Parameters:
    - share_name -- The file share name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - exclude_dir -- None
    - marker --  An opaque continuation token. This value can be retrieved from the next_marker field of a previous generator object if num_results was specified and that generator has finished enumerating results. If specified, this generator will begin returning results from the point where the previous generator stopped.
    - num_results -- Specify the maximum number to return. If the request does not specify num_results, or specifies a value greater than 5000, the server will return up to 5000 items. Note that if the listing operation crosses a partition boundary, then the service will return a continuation token for retrieving the remaining of the results. Provide "*" to return all.
    - path -- The directory path within the file share.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - snapshot --  A string that represents the snapshot version, if applicable.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage file list", locals())


def delete(path, share_name, account_key=None, account_name=None, connection_string=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - path -- The path to the file within the file share.
    - share_name -- The file share name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage file delete", locals())


def resize(path, share_name, size, account_key=None, account_name=None, connection_string=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - path -- The path to the file within the file share.
    - share_name -- The file share name.
    - size --  The length to resize the file to.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage file resize", locals())


def url(path, share_name, account_key=None, account_name=None, connection_string=None, protocol=None, sas_token=None):
    '''
    Create the url to access a file.

    Required Parameters:
    - path -- The path to the file within the file share.
    - share_name -- The file share name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - protocol -- Protocol to use.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    '''
    return _call_az("az storage file url", locals())


def generate_sas(path, share_name, account_key=None, account_name=None, cache_control=None, connection_string=None, content_disposition=None, content_encoding=None, content_language=None, content_type=None, expiry=None, https_only=None, ip=None, permissions=None, policy_name=None, start=None):
    '''
    

    Required Parameters:
    - path -- The path to the file within the file share.
    - share_name -- The file share name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - cache_control --  Response header value for Cache-Control when resource is accessed using this shared access signature.
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - content_disposition --  Response header value for Content-Disposition when resource is accessed using this shared access signature.
    - content_encoding --  Response header value for Content-Encoding when resource is accessed using this shared access signature.
    - content_language --  Response header value for Content-Language when resource is accessed using this shared access signature.
    - content_type --  Response header value for Content-Type when resource is accessed using this shared access signature.
    - expiry -- Specifies the UTC datetime (Y-m-d'T'H:M'Z') at which the SAS becomes invalid. Do not use if a stored access policy is referenced with --id that specifies this value.
    - https_only -- Only permit requests made with the HTTPS protocol. If omitted, requests from both the HTTP and HTTPS protocol are permitted.
    - ip -- Specifies the IP address or range of IP addresses from which to accept requests. Supports only IPv4 style addresses.
    - permissions -- The permissions the SAS grants. Allowed values: (c)reate (d)elete (r)ead (w)rite (c)reate (d)elete (r)ead (w)rite. Do not use if a stored access policy is referenced with --id that specifies this value. Can be combined.
    - policy_name -- The name of a stored access policy within the container's ACL.
    - start -- Specifies the UTC datetime (Y-m-d'T'H:M'Z') at which the SAS becomes valid. Do not use if a stored access policy is referenced with --id that specifies this value. Defaults to the time of the request.
    '''
    return _call_az("az storage file generate-sas", locals())


def show(path, share_name, account_key=None, account_name=None, connection_string=None, sas_token=None, snapshot=None, timeout=None):
    '''
    

    Required Parameters:
    - path -- The path to the file within the file share.
    - share_name -- The file share name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - snapshot --  A string that represents the snapshot version, if applicable.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage file show", locals())


def update(path, share_name, account_key=None, account_name=None, clear_content_settings=None, connection_string=None, content_cache_control=None, content_disposition=None, content_encoding=None, content_language=None, content_md5=None, content_type=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - path -- The path to the file within the file share.
    - share_name -- The file share name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - clear_content_settings -- If this flag is set, then if any one or more of the following properties (--content-cache-control, --content-disposition, --content-encoding, --content-language, --content-md5, --content-type) is set, then all of these properties are set together. If a value is not provided for a given property when at least one of the properties listed below is set, then that property will be cleared.
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - content_cache_control -- The cache control string.
    - content_disposition -- Conveys additional information about how to process the response payload, and can also be used to attach additional metadata.
    - content_encoding -- The content encoding type.
    - content_language -- The content language.
    - content_md5 -- The content's MD5 hash.
    - content_type -- The content MIME type.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage file update", locals())


def exists(path, share_name, account_key=None, account_name=None, connection_string=None, sas_token=None, snapshot=None, timeout=None):
    '''
    Check for the existence of a file.

    Required Parameters:
    - path -- The path to the file within the file share.
    - share_name -- The file share name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - snapshot --  A string that represents the snapshot version, if applicable.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage file exists", locals())


def download(path, share_name, account_key=None, account_name=None, connection_string=None, dest=None, end_range=None, max_connections=None, no_progress=None, open_mode=None, sas_token=None, snapshot=None, start_range=None, timeout=None, validate_content=None):
    '''
    

    Required Parameters:
    - path -- The path to the file within the file share.
    - share_name -- The file share name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - dest -- Path of the file to write to. The source filename will be used if not specified.
    - end_range --  End of byte range to use for downloading a section of the file. If end_range is given, start_range must be provided. The start_range and end_range params are inclusive. Ex: start_range=0, end_range=511 will download first 512 bytes of file.
    - max_connections --  If set to 2 or greater, an initial get will be done for the first self.MAX_SINGLE_GET_SIZE bytes of the file. If this is the entire file, the method returns at this point. If it is not, it will download the remaining data parallel using the number of threads equal to max_connections. Each chunk will be of size self.MAX_CHUNK_GET_SIZE. If set to 1, a single large get request will be done. This is not generally recommended but available if very few threads should be used, network requests are very expensive, or a non-seekable stream prevents parallel download. This may also be valuable if the file is being concurrently modified to enforce atomicity or if many files are expected to be empty as an extra request is required for empty files if max_connections is greater than 1.
    - no_progress -- Include this flag to disable progress reporting for the command.
    - open_mode --  Mode to use when opening the file. Note that specifying append only open_mode prevents parallel download. So, max_connections must be set to 1 if this open_mode is used.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - snapshot --  A string that represents the snapshot version, if applicable.
    - start_range --  Start of byte range to use for downloading a section of the file. If no end_range is given, all bytes after the start_range will be downloaded. The start_range and end_range params are inclusive. Ex: start_range=0, end_range=511 will download first 512 bytes of file.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    - validate_content --  If set to true, validates an MD5 hash for each retrieved portion of the file. This is primarily valuable for detecting bitflips on the wire if using http instead of https as https (the default) will already validate. Note that the service will only return transactional MD5s for chunks 4MB or less so the first get request will be of size self.MAX_CHUNK_GET_SIZE instead of self.MAX_SINGLE_GET_SIZE. If self.MAX_CHUNK_GET_SIZE was set to greater than 4MB an error will be thrown. As computing the MD5 takes processing time and more requests will need to be done due to the reduced chunk size there may be some increase in latency.
    '''
    return _call_az("az storage file download", locals())


def upload(share_name, source, account_key=None, account_name=None, connection_string=None, content_cache_control=None, content_disposition=None, content_encoding=None, content_language=None, content_md5=None, content_type=None, max_connections=None, metadata=None, no_progress=None, path=None, sas_token=None, timeout=None, validate_content=None):
    '''
    Upload a file to a share that uses the SMB 3.0 protocol.

    Required Parameters:
    - share_name -- The file share name.
    - source --  Path of the local file to upload as the file content.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - content_cache_control -- The cache control string.
    - content_disposition -- Conveys additional information about how to process the response payload, and can also be used to attach additional metadata.
    - content_encoding -- The content encoding type.
    - content_language -- The content language.
    - content_md5 -- The content's MD5 hash.
    - content_type -- The content MIME type.
    - max_connections --  Maximum number of parallel connections to use.
    - metadata -- Metadata in space-separated key=value pairs. This overwrites any existing metadata.
    - no_progress -- Include this flag to disable progress reporting for the command.
    - path -- The path to the file within the file share. If the file name is omitted, the source file name will be used.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    - validate_content --  If true, calculates an MD5 hash for each range of the file. The storage service checks the hash of the content that has arrived with the hash that was sent. This is primarily valuable for detecting bitflips on the wire if using http instead of https as https (the default) will already validate. Note that this MD5 hash is not stored with the file.
    '''
    return _call_az("az storage file upload", locals())


def upload_batch(destination, source, account_key=None, account_name=None, connection_string=None, content_cache_control=None, content_disposition=None, content_encoding=None, content_language=None, content_md5=None, content_type=None, destination_path=None, dryrun=None, max_connections=None, metadata=None, no_progress=None, pattern=None, sas_token=None, validate_content=None):
    '''
    Upload files from a local directory to an Azure Storage File Share in a batch operation.

    Required Parameters:
    - destination -- None
    - source -- None

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - content_cache_control -- The cache control string.
    - content_disposition -- Conveys additional information about how to process the response payload, and can also be used to attach additional metadata.
    - content_encoding -- The content encoding type.
    - content_language -- The content language.
    - content_md5 -- The content's MD5 hash.
    - content_type -- The content MIME type.
    - destination_path -- None
    - dryrun -- None
    - max_connections -- None
    - metadata -- Metadata in space-separated key=value pairs. This overwrites any existing metadata.
    - no_progress -- Include this flag to disable progress reporting for the command.
    - pattern -- None
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - validate_content -- None
    '''
    return _call_az("az storage file upload-batch", locals())


def download_batch(destination, source, account_key=None, account_name=None, connection_string=None, dryrun=None, max_connections=None, no_progress=None, pattern=None, sas_token=None, snapshot=None, validate_content=None):
    '''
    Download files from an Azure Storage File Share to a local directory in a batch operation.

    Required Parameters:
    - destination -- None
    - source -- None

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - dryrun -- None
    - max_connections -- None
    - no_progress -- Include this flag to disable progress reporting for the command.
    - pattern -- None
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - snapshot -- None
    - validate_content -- None
    '''
    return _call_az("az storage file download-batch", locals())


def delete_batch(source, account_key=None, account_name=None, connection_string=None, dryrun=None, pattern=None, sas_token=None, timeout=None):
    '''
    Delete files from an Azure Storage File Share.

    Required Parameters:
    - source -- None

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - dryrun -- None
    - pattern -- None
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage file delete-batch", locals())




'''
Manage blob storage container leases.
'''
from .... pyaz_utils import _call_az

def acquire(container_name, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_modified_since=None, if_unmodified_since=None, lease_duration=None, proposed_lease_id=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - container_name -- The container name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - if_modified_since -- Commence only if modified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - if_unmodified_since -- Commence only if unmodified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - lease_duration --  Specifies the duration of the lease, in seconds, or negative one (-1) for a lease that never expires. A non-infinite lease can be between 15 and 60 seconds. A lease duration cannot be changed using renew or change. Default is -1 (infinite lease).
    - proposed_lease_id --  Proposed lease ID, in a GUID string format. The Blob service returns 400 (Invalid request) if the proposed lease ID is not in the correct format.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage container lease acquire", locals())


def renew(container_name, lease_id, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_modified_since=None, if_unmodified_since=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - container_name -- The container name.
    - lease_id --  Lease ID for active lease.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - if_modified_since -- Commence only if modified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - if_unmodified_since -- Commence only if unmodified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage container lease renew", locals())


def release(container_name, lease_id, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_modified_since=None, if_unmodified_since=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - container_name -- The container name.
    - lease_id --  Lease ID for active lease.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - if_modified_since -- Commence only if modified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - if_unmodified_since -- Commence only if unmodified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage container lease release", locals())


def change(container_name, lease_id, proposed_lease_id, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_modified_since=None, if_unmodified_since=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - container_name -- The container name.
    - lease_id --  Lease ID for active lease.
    - proposed_lease_id --  Proposed lease ID, in a GUID string format. The Blob service returns 400 (Invalid request) if the proposed lease ID is not in the correct format.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - if_modified_since -- Commence only if modified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - if_unmodified_since -- Commence only if unmodified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage container lease change", locals())


def break_(container_name, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_modified_since=None, if_unmodified_since=None, lease_break_period=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - container_name -- The container name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - if_modified_since -- Commence only if modified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - if_unmodified_since -- Commence only if unmodified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - lease_break_period --  This is the proposed duration of seconds that the lease should continue before it is broken, between 0 and 60 seconds. This break period is only used if it is shorter than the time remaining on the lease. If longer, the time remaining on the lease is used. A new lease will not be available before the break period has expired, but the lease may be held for longer than the break period. If this header does not appear with a break operation, a fixed-duration lease breaks after the remaining lease period elapses, and an infinite lease breaks immediately.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage container lease break", locals())




'''
Manage registered Azure clouds.
'''
from .. pyaz_utils import _call_az

def list():
    '''
    List registered clouds.
    '''
    return _call_az("az cloud list", locals())


def show(name=None):
    '''
    Get the details of a registered cloud.

    Optional Parameters:
    - name -- Name of a registered cloud.
    '''
    return _call_az("az cloud show", locals())


def register(name, cloud_config=None, endpoint_active_directory=None, endpoint_active_directory_data_lake_resource_id=None, endpoint_active_directory_graph_resource_id=None, endpoint_active_directory_resource_id=None, endpoint_gallery=None, endpoint_management=None, endpoint_resource_manager=None, endpoint_sql_management=None, endpoint_vm_image_alias_doc=None, profile=None, suffix_acr_login_server_endpoint=None, suffix_azure_datalake_analytics_catalog_and_job_endpoint=None, suffix_azure_datalake_store_file_system_endpoint=None, suffix_keyvault_dns=None, suffix_sql_server_hostname=None, suffix_storage_endpoint=None):
    '''
    Register a cloud.

    Required Parameters:
    - name -- Name of a registered cloud

    Optional Parameters:
    - cloud_config -- JSON encoded cloud configuration. Use @{file} to load from a file.
    - endpoint_active_directory -- The Active Directory login endpoint
    - endpoint_active_directory_data_lake_resource_id -- The Active Directory resource ID for data lake services
    - endpoint_active_directory_graph_resource_id -- The Active Directory resource ID
    - endpoint_active_directory_resource_id -- The resource ID to obtain AD tokens for
    - endpoint_gallery -- The template gallery endpoint
    - endpoint_management -- The management service endpoint
    - endpoint_resource_manager -- The resource management endpoint
    - endpoint_sql_management -- The sql server management endpoint
    - endpoint_vm_image_alias_doc -- The uri of the document which caches commonly used virtual machine images
    - profile -- Profile to use for this cloud
    - suffix_acr_login_server_endpoint -- The Azure Container Registry login server suffix
    - suffix_azure_datalake_analytics_catalog_and_job_endpoint -- The Data Lake analytics job and catalog service dns suffix
    - suffix_azure_datalake_store_file_system_endpoint -- The Data Lake store filesystem service dns suffix
    - suffix_keyvault_dns -- The Key Vault service dns suffix
    - suffix_sql_server_hostname -- The dns suffix for sql servers
    - suffix_storage_endpoint -- The endpoint suffix for storage accounts
    '''
    return _call_az("az cloud register", locals())


def unregister(name):
    '''
    Unregister a cloud.

    Required Parameters:
    - name -- Name of a registered cloud
    '''
    return _call_az("az cloud unregister", locals())


def set(name, profile=None):
    '''
    Set the active cloud.

    Required Parameters:
    - name -- Name of a registered cloud

    Optional Parameters:
    - profile -- Profile to use for this cloud
    '''
    return _call_az("az cloud set", locals())


def update(cloud_config=None, endpoint_active_directory=None, endpoint_active_directory_data_lake_resource_id=None, endpoint_active_directory_graph_resource_id=None, endpoint_active_directory_resource_id=None, endpoint_gallery=None, endpoint_management=None, endpoint_resource_manager=None, endpoint_sql_management=None, endpoint_vm_image_alias_doc=None, name=None, profile=None, suffix_acr_login_server_endpoint=None, suffix_azure_datalake_analytics_catalog_and_job_endpoint=None, suffix_azure_datalake_store_file_system_endpoint=None, suffix_keyvault_dns=None, suffix_sql_server_hostname=None, suffix_storage_endpoint=None):
    '''
    Update the configuration of a cloud.

    Optional Parameters:
    - cloud_config -- JSON encoded cloud configuration. Use @{file} to load from a file.
    - endpoint_active_directory -- The Active Directory login endpoint
    - endpoint_active_directory_data_lake_resource_id -- The Active Directory resource ID for data lake services
    - endpoint_active_directory_graph_resource_id -- The Active Directory resource ID
    - endpoint_active_directory_resource_id -- The resource ID to obtain AD tokens for
    - endpoint_gallery -- The template gallery endpoint
    - endpoint_management -- The management service endpoint
    - endpoint_resource_manager -- The resource management endpoint
    - endpoint_sql_management -- The sql server management endpoint
    - endpoint_vm_image_alias_doc -- The uri of the document which caches commonly used virtual machine images
    - name -- Name of a registered cloud.
    - profile -- Profile to use for this cloud
    - suffix_acr_login_server_endpoint -- The Azure Container Registry login server suffix
    - suffix_azure_datalake_analytics_catalog_and_job_endpoint -- The Data Lake analytics job and catalog service dns suffix
    - suffix_azure_datalake_store_file_system_endpoint -- The Data Lake store filesystem service dns suffix
    - suffix_keyvault_dns -- The Key Vault service dns suffix
    - suffix_sql_server_hostname -- The dns suffix for sql servers
    - suffix_storage_endpoint -- The endpoint suffix for storage accounts
    '''
    return _call_az("az cloud update", locals())


def list_profiles(name=None, show_all=None):
    '''
    List the supported profiles for a cloud.

    Optional Parameters:
    - name -- Name of a registered cloud.
    - show_all -- Show all available profiles supported in the CLI.
    '''
    return _call_az("az cloud list-profiles", locals())




'''
Shows the Azure Security Center Home region location.
'''
from ... pyaz_utils import _call_az

def list():
    '''
    Shows the Azure Security Center Home region location.
    '''
    return _call_az("az security location list", locals())


def show(name):
    '''
    Shows the Azure Security Center Home region location.

    Required Parameters:
    - name -- name of the resource to be fetched
    '''
    return _call_az("az security location show", locals())

